# Distributed under the OSI-approved BSD 3-Clause License.  See accompanying
# file Copyright.txt or https://cmake.org/licensing for details.
# Copyright (c) 2020 Pavel "Malo" Skrylev <majioa@yandex.ru>
#
#[=======================================================================[.rst:
FindOpenMesh

Find OpenMesh include folders and libraries

Use as follows:

find_library(OpenMesh)

This module finds headers and requested component libraries. For the former
case results are reported in variables:

  OPENMESH_FOUND             - True if headers and requested libraries were found
  OPENMESH_INCLUDE_DIR       - OpenMesh include directories
  OPENMESH_LIBRARIES         - OpenMesh libraries list

This module reads hints about search locations from variables:

  OPENMESH_ROOT_HINTS        - Preferred installation prefix
  OPENMESH_INCLUDE_DIR_HINTS - Preferred include directory e.g. <prefix>/include

  Example to find OpenMesh headers only:

  find_package(OpenMesh)
  if(OPENMESH_FOUND)
    include_directories(${OPENMESH_INCLUDE_DIR})
  endif()

#]=======================================================================]

if(NOT OPENMESH_INCLUDE_DIR)
   find_path(OPENMESH_INCLUDE_DIR
      NAMES
         Core
	 Tools
      HINTS
         ENV OPENMESH_INCLUDE_DIR_HINTS
         ENV OPENMESH_ROOT_HINT
      PATHS
         ${CMAKE_INSTALL_PREFIX}/include
      PATH_SUFFIXES
         OpenMesh
   )

   if(OPENMESH_INCLUDE_DIR)
      include(FindPackageHandleStandardArgs)
      find_package_handle_standard_args(OpenMesh DEFAULT_MSG OPENMESH_INCLUDE_DIR)

      find_library(OPENMESH_LIBRARY1
         NAMES
	    libOpenMeshCore.so
         HINTS
	    ENV OPENMESH_LIBRARY_HINTS
	    ENV OPENMESH_ROOT_HINT
	    ${CMAKE_${LANG}_IMPLICIT_LINK_DIRECTORIES}
	    ${CMAKE_PLATFORM_IMPLICIT_LINK_DIRECTORIES}
	 REQUIRED
      )

      find_library(OPENMESH_LIBRARY2
         NAMES
            libOpenMeshTools.so
         HINTS
	    ENV OPENMESH_LIBRARY_HINTS
	    ENV OPENMESH_ROOT_HINT
	    ${CMAKE_${LANG}_IMPLICIT_LINK_DIRECTORIES}
	    ${CMAKE_PLATFORM_IMPLICIT_LINK_DIRECTORIES}
	 REQUIRED
      )

      add_library(OpenMesh INTERFACE)
      target_link_libraries(OpenMesh
         INTERFACE
            OpenMeshCore
            OpenMeshTools)

      set(OPENMESH_LIBRARIES ${OPENMESH_LIBRARY1} ${OPENMESH_LIBRARY2})

      if(OPENMESH_LIBRARIES)
         set(OPENMESH_FOUND TRUE)

	 message(STATUS "OpenMesh found libs ${OPENMESH_LIBRARIES} with headers in ${OPENMESH_INCLUDE_DIR}")

	 mark_as_advanced(OpenMesh OPENMESH_INCLUDE_DIR OPENMESH_LIBRARIES)
      endif(OPENMESH_LIBRARIES)
   endif(OPENMESH_INCLUDE_DIR)
endif(NOT OPENMESH_INCLUDE_DIR)
